==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_download.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_download.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Downloads");

define("LAN_dl_1", "(Restricted)");
define("LAN_dl_2", "No downloads yet, please check back soon");
define("LAN_dl_3", "No downloads in this category yet");
define("LAN_dl_4", "Files available: ");
define("LAN_dl_5", "Total size of files: ");
define("LAN_dl_6", "Files downloaded: ");
define("LAN_dl_7", "Description");
define("LAN_dl_8", "Get");
define("LAN_dl_9", "Return to Category List");
define("LAN_dl_10", "Filesize");
define("LAN_dl_11", "Image");
define("LAN_dl_12", "Rating");
define("LAN_dl_13", "Not rated");
define("LAN_dl_14", "Rate this download");
define("LAN_dl_15", "Thanks for rating");
define("LAN_dl_16", "download(s) from");
define("LAN_dl_17", "files");
define("LAN_dl_18", "Downloads");			// Page title
define("LAN_dl_19", "Category");
define("LAN_dl_20", "Files");
define("LAN_dl_21", "Size");
define("LAN_dl_22", "Date");
define("LAN_dl_23", "Filename");
define("LAN_dl_24", "Author");
define("LAN_dl_25", "Ascending");
define("LAN_dl_26", "Descending");
define("LAN_dl_27", "Go");
define("LAN_dl_28", "Name");
define("LAN_dl_29", "DL's");
define("LAN_dl_30", "Author email");
define("LAN_dl_31", "Author website");
define("LAN_dl_32", "Download");
define("LAN_dl_33", "Previous");
define("LAN_dl_34", "Next");
define("LAN_dl_35", "Back to list");
define("LAN_dl_36", "New downloads");

define("LAN_dl_37", "View");
define("LAN_dl_38", "Order by");
define("LAN_dl_39", "Sort");

define("LAN_dl_40", "Click here for screenshot");
define("LAN_dl_41", "Search Downloads");

define("LAN_dl_42", "Sub-category");
define("LAN_dl_43", "vote");
define("LAN_dl_44", "votes");
define("LAN_dl_45", "Report broken download");
define("LAN_dl_46", "click here to download");

define("LAN_dl_47", "Post has been reported");
define("LAN_dl_48", "Download has been reported to administrator.<br />Thank you.");
define("LAN_dl_49", "Click here to return to download");
define("LAN_dl_50", "Report broken download to an administrator");
define("LAN_dl_51", "Reporting download: ");
define("LAN_dl_52", "Guest");
define("LAN_dl_53", "Click to view download");
define("LAN_dl_54", "An administrator will be made aware of this download, please leave a message if you feel it necessary.");
define("LAN_dl_55", "<b>Do not</b> use this form to contact the admin for any other reason.");
// define("LAN_dl_56", "Report broken download");  already defined above.
define("LAN_dl_57", "reported by");
define("LAN_dl_58", "The following download has been reported as broken from site");
define("LAN_dl_59", "Reported by: ");
define("LAN_dl_60", "Broken download report from");

define("LAN_dl_61", "Download Error");
define("LAN_dl_62", "You have been prevented from downloading this file; you have exceeded your download quota");
define("LAN_dl_63", "You do not have the correct permissions to download this file.");
define("LAN_dl_64", "Back");
define("LAN_dl_65", "File Not Found");

define("LAN_dl_66", "Select download mirror");

define("LAN_dl_67", "Please select mirror to use ...");
define("LAN_dl_68", "Mirror Host");
// define("LAN_dl_69", "Download"); // duplicate
define("LAN_dl_70", "Location");
define("LAN_dl_71", "About");

define("LAN_dl_72", "Requesting file: ");
define("LAN_dl_73", "Downloads from this mirror: ");
define("LAN_dl_74", "Total downloads from this mirror: ");

define("LAN_dl_75", "no image available ");
define("LAN_dl_76", "Go to page");
define("LAN_dl_77", "Downloads");		// Intentional duplicate - some languages need it to be different. This is for number of downloads

define('LAN_dl_78', 'That download has been disabled or discontinued. Please check in the --LINK--downloads</a> area for a more recent version.'); 

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_download.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_download.php $
|     $Revision: 12054 $
|     $Id: lan_download.php 12054 2011-01-22 02:11:39Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Downloads");

define("LAN_dl_1", "(Restricted)");
define("LAN_dl_2", "No downloads yet, please check back soon");
define("LAN_dl_3", "No downloads in this category yet");
define("LAN_dl_4", "Files available: ");
define("LAN_dl_5", "Total size of files: ");
define("LAN_dl_6", "Files downloaded: ");
define("LAN_dl_7", "Description");
define("LAN_dl_8", "Get");
define("LAN_dl_9", "Return to Category List");
define("LAN_dl_10", "Filesize");
define("LAN_dl_11", "Image");
define("LAN_dl_12", "Rating");
define("LAN_dl_13", "Not rated");
define("LAN_dl_14", "Rate this download");
define("LAN_dl_15", "Thanks for rating");
define("LAN_dl_16", "download(s) from");
define("LAN_dl_17", "files");
define("LAN_dl_18", "Downloads");			// Page title
define("LAN_dl_19", "Category");
define("LAN_dl_20", "Files");
define("LAN_dl_21", "Size");
define("LAN_dl_22", "Date");
define("LAN_dl_23", "Filename");
define("LAN_dl_24", "Author");
define("LAN_dl_25", "Ascending");
define("LAN_dl_26", "Descending");
define("LAN_dl_27", "Go");
define("LAN_dl_28", "Name");
define("LAN_dl_29", "DL's");
define("LAN_dl_30", "Author email");
define("LAN_dl_31", "Author website");
define("LAN_dl_32", "Download");
define("LAN_dl_33", "Previous");
define("LAN_dl_34", "Next");
define("LAN_dl_35", "Back to list");
define("LAN_dl_36", "New downloads");

define("LAN_dl_37", "View");
define("LAN_dl_38", "Order by");
define("LAN_dl_39", "Sort");

define("LAN_dl_40", "Click here for screenshot");
define("LAN_dl_41", "Search Downloads");

define("LAN_dl_42", "Sub-category");
define("LAN_dl_43", "vote");
define("LAN_dl_44", "votes");
define("LAN_dl_45", "Report broken download");
define("LAN_dl_46", "click here to download");

define("LAN_dl_47", "Post has been reported");
define("LAN_dl_48", "Download has been reported to administrator.<br />Thank you.");
define("LAN_dl_49", "Click here to return to download");
define("LAN_dl_50", "Report broken download to an administrator");
define("LAN_dl_51", "Reporting download: ");
define("LAN_dl_52", "Guest");
define("LAN_dl_53", "Click to view download");
define("LAN_dl_54", "An administrator will be made aware of this download, please leave a message if you feel it necessary.");
define("LAN_dl_55", "<b>Do not</b> use this form to contact the admin for any other reason.");
// define("LAN_dl_56", "Report broken download");  already defined above.
define("LAN_dl_57", "reported by");
define("LAN_dl_58", "The following download has been reported as broken from site");
define("LAN_dl_59", "Reported by: ");
define("LAN_dl_60", "Broken download report from");

define("LAN_dl_61", "Download Error");
define("LAN_dl_62", "You have been prevented from downloading this file; you have exceeded your download quota");
define("LAN_dl_63", "You do not have the correct permissions to download this file.");
define("LAN_dl_64", "Back");
define("LAN_dl_65", "File Not Found");

define("LAN_dl_66", "Select download mirror");

define("LAN_dl_67", "Please select mirror to use ...");
define("LAN_dl_68", "Mirror Host");
// define("LAN_dl_69", "Download"); // duplicate
define("LAN_dl_70", "Location");
define("LAN_dl_71", "About");

define("LAN_dl_72", "Requesting file: ");
define("LAN_dl_73", "Downloads from this mirror: ");
define("LAN_dl_74", "Total downloads from this mirror: ");

define("LAN_dl_75", "no image available ");
define("LAN_dl_76", "Go to page");
define("LAN_dl_77", "Downloads");		// Intentional duplicate - some languages need it to be different. This is for number of downloads

//0.7.23
define("LAN_dl_78", "That download has been disabled or discontinued. Please check in the [downloads] area for a more recent version."); 
define("LAN_dl_79", "Please wait a few moments before [downloading again].");
define("LAN_dl_80", "Please enable cookies and [try again].");
define("LAN_dl_81", "Cookies Required");
define("LAN_dl_82", "Please Wait");

//0.7.25

define("LAN_dl_83", "Your download will begin in a moment...");
define("LAN_dl_84", "If your download doesn't start within a few seconds, please [click here].");

?>
